@@ -49,7 +49,7 @@ agreement No 676548 (the BrightnESS project)
 
 __license__ = "Apache 2.0, http://www.apache.org/licenses/LICENSE-2.0"
 __copyright__ = 'Copyright 2015-2025'
-__version__ = '1.9.80'
+__version__ = '2.0.0'
 __status__ = 'Production'
 __author__ = 'Thomas Kittelmann'
 __maintainer__ = 'Thomas Kittelmann'
@@ -1201,7 +1201,7 @@ def app_pymcpltool(argv=None):
     if opt_version:
         if filelist:
             bad("Unrecognised arguments for --version.")
-        print("MCPL version %s"%__version__)
+        print("MCPL version %s"%_determine_version())
         sys.exit(0)
 
     if opt_text:
@@ -1736,12 +1736,20 @@ def plot_stats(stats,pdf=False,set_backend=None):
     if pdf:
         if hasattr(pdf,'infodict'):
             d = pdf.infodict()
-            d['Title'] = 'Plots made with mcpl.py version %s'%__version__
-            d['Author'] = 'mcpl.py v%s'%__version__
+            d['Title'] = ( 'Plots made with mcpl.py version %s'
+                           % _determine_version() )
+            d['Author'] = 'mcpl.py v%s' % _determine_version()
             d['Subject'] = 'mcpl plots'
             d['Keywords'] = 'mcpl'
         pdf.close()
 
+def _determine_version():
+    if os.environ.get('PYMCPLTOOL_FAKE_PYVERSION','').strip():
+        return '99.99.99'
+    else:
+        return __version__
+
+
 def main():
     """This function simply calls app_pymcpltool(), but any raised MCPLError
     exception will be caught and transformed into a corresponding error message
